@@ -73,7 +73,6 @@ fn build_capstone_cc() {
 
         read_dir(dir)
             .expect("Failed to read capstone source directory")
-            .into_iter()
             .map(|e| e.expect("Failed to read capstone source directory"))
             .filter(|e| filter(e))
             .map(|e| {
@@ -109,13 +108,14 @@ fn build_capstone_cc() {
     for arch_dir in find_arch_dirs().into_iter() {
         files.append(&mut find_c_source_files(&arch_dir));
     }
-
+    // keep build reproducible
+    files.sort();
     let use_static_crt = {
         let target_features = env::var("CARGO_CFG_TARGET_FEATURE").unwrap_or_default();
         target_features.split(',').any(|f| f == "crt-static")
     };
-
-    cc::Build::new()
+    let mut builder = cc::Build::new();
+    builder
         .files(files)
         .include(format!("{}/{}", CAPSTONE_DIR, "include"))
         .define("CAPSTONE_USE_SYS_DYN_MEM", None)
@@ -133,16 +133,16 @@ fn build_capstone_cc() {
         .define("CAPSTONE_HAS_WASM", None)
         .define("CAPSTONE_HAS_X86", None)
         .define("CAPSTONE_HAS_XCORE", None)
-        .flag_if_supported("-Wno-unused-function")
-        .flag_if_supported("-Wno-unused-parameter")
-        .flag_if_supported("-Wno-unknown-pragmas")
-        .flag_if_supported("-Wno-sign-compare")
-        .flag_if_supported("-Wno-return-type")
-        .flag_if_supported("-Wno-implicit-fallthrough")
-        .flag_if_supported("-Wno-missing-field-initializers")
-        .flag_if_supported("-Wno-enum-conversion")
-        .static_crt(use_static_crt)
-        .compile("capstone");
+        .define("CAPSTONE_HAS_BPF", None)
+        // No need to display any warnings from the C library
+        .flag_if_supported("-w")
+        .static_crt(use_static_crt);
+
+    if !cfg!(feature = "full") {
+        builder.define("CAPSTONE_DIET", "yes");
+    }
+
+    builder.compile("capstone");
 }
 
 /// Search for header in search paths
@@ -166,6 +166,8 @@ fn env_var(var: &str) -> String {
 /// instructions enum declaration.
 #[cfg(feature = "use_bindgen")]
 fn impl_insid_to_insenum(bindings: &str) -> String {
+    use std::fmt::Write as _;
+
     let mut impl_arch_enum = String::new();
     impl_arch_enum.push_str("use core::convert::From;\n");
 
@@ -186,42 +188,42 @@ fn impl_insid_to_insenum(bindings: &str) -> String {
         ))
         .expect("Unable to compile regex");
 
-        impl_arch_enum.push_str(&format!(
+        write!(
+            impl_arch_enum,
             "impl From<u32> for {}_insn {{\n
             fn from(id: u32) -> Self {{\n
             match id {{\n",
             &arch
-        ));
+        )
+        .unwrap();
 
         // fill match expression
         for cap_ins_id in re_ins_ids.captures_iter(cap_enum_def) {
-            impl_arch_enum.push_str(&format!(
-                "{} => {}_insn::{}_INS_{},\n",
+            writeln!(
+                impl_arch_enum,
+                "{} => {}_insn::{}_INS_{},",
                 &cap_ins_id["id"],
                 &arch,
                 &arch.to_uppercase(),
                 &cap_ins_id["ins"]
-            ));
+            )
+            .unwrap();
         }
 
         // if id didn't match, return [arch]_INS_INVALID.
         // special case for m680x which has 'INVLD' variant instead of 'INVALID'
-        match arch {
-            "m680x" => {
-                impl_arch_enum.push_str(&format!(
-                    "_ => {}_insn::{}_INS_INVLD,",
-                    &arch,
-                    &arch.to_uppercase()
-                ));
-            }
-            _ => {
-                impl_arch_enum.push_str(&format!(
-                    "_ => {}_insn::{}_INS_INVALID,",
-                    &arch,
-                    &arch.to_uppercase()
-                ));
-            }
-        }
+        let invalid_str = match arch {
+            "m680x" => "INVLD",
+            _ => "INVALID",
+        };
+        write!(
+            impl_arch_enum,
+            "_ => {}_insn::{}_INS_{},",
+            &arch,
+            &arch.to_uppercase(),
+            invalid_str,
+        )
+        .unwrap();
 
         impl_arch_enum.push_str("}\n}\n}\n");
     }
@@ -239,8 +241,9 @@ fn write_bindgen_bindings(
     out_bindings_path: PathBuf,
     out_impl_path: PathBuf,
 ) {
+    #[allow(deprecated)]
     let mut builder = bindgen::Builder::default()
-        .rust_target(bindgen::RustTarget::Stable_1_19)
+        .rust_target(bindgen::RustTarget::Stable_1_28)
         .size_t_is_usize(true)
         .use_core()
         .ctypes_prefix("libc")
@@ -356,9 +359,8 @@ fn main() {
     // Otherwise, copy the pregenerated bindings
     #[cfg(not(feature = "use_bindgen"))]
     {
-        copy(&pregenerated_bindgen_header, &out_bindings_path)
-            .expect("Unable to update capstone bindings");
-        copy(&pregenerated_bindgen_impl, &out_impl_path)
+        copy(pregenerated_bindgen_header, out_bindings_path)
             .expect("Unable to update capstone bindings");
+        copy(pregenerated_bindgen_impl, out_impl_path).expect("Unable to update capstone bindings");
     }
 }
