@@ -12,7 +12,7 @@ pub struct CapstoneArchInfo<'a> {
     cs_name: &'a str,
 }
 
-impl<'a> CapstoneArchInfo<'a> {
+impl CapstoneArchInfo<'_> {
     /// Get the name of the C header
     pub fn header_name(&self) -> &str {
         self.header_name
@@ -77,6 +77,10 @@ pub static ARCH_INCLUDES: &[CapstoneArchInfo<'static>] = &[
         header_name: "xcore.h",
         cs_name: "xcore",
     },
+    CapstoneArchInfo {
+        header_name: "bpf.h",
+        cs_name: "bpf"
+    }
 ];
 
 pub static BINDINGS_FILE: &str = "capstone.rs";
